timespantools.timespan_2_starts_when_timespan_1_starts
======================================================

.. autofunction:: abjad.tools.timespantools.timespan_2_starts_when_timespan_1_starts.timespan_2_starts_when_timespan_1_starts
